@@ -9,12 +9,12 @@ sub register_rules {
 	my ($self, $rule, $pkg_name, $sub_name) = @_;
 
 	my ($pkg_names, $sub_names);
-	if(ref($pkg_name) eq 'ARRAY') {
+	if (ref($pkg_name) eq 'ARRAY') {
 		$pkg_names = $pkg_name
 	} else {
 		$pkg_names = [$pkg_name];
 	}
-	if(ref($sub_name) eq 'ARRAY') {
+	if (ref($sub_name) eq 'ARRAY') {
 		$sub_names = $sub_name
 	} else {
 		$sub_names = [$sub_name];
@@ -29,15 +29,15 @@ sub register_rules {
 sub register_rule {
 	my ($self, $rule, $pkg_name, $sub_name) = @_;
 
-	if ( length($pkg_name) and ($pkg_name !~ m,^((\w+)($|\:\:))+$,)) {
+	if ($pkg_name !~ m,^((\w+)($|\:\:))*$,) {
 		Carp::confess("Package name '$pkg_name' is not valid.\n");
 	}
-	$self->{$pkg_name} = {} unless (exists($self->{$pkg_name}));
-
-	my $pkg_rules = $self->{$pkg_name};
 	unless ($sub_name =~ m,^\w*$,) {
 		Carp::confess("Subroutine name '$sub_name' is not valid.\n");
 	}
+
+	$self->{$pkg_name} = {} unless (exists($self->{$pkg_name}));
+	my $pkg_rules = $self->{$pkg_name};
 	$pkg_rules->{$sub_name} = [] unless (exists($pkg_rules->{$sub_name}));
 	my $sub_rules = $pkg_rules->{$sub_name};
 
@@ -45,21 +45,11 @@ sub register_rule {
 	return;
 }
 
-
-#sub any_rules {
-#	my ($self, $pkg_name, $sub_name) = @_;
-#
-#	return(0) unless (exists($self->{$pkg_name}));
-#	return(0) unless (exists($self->{$pkg_name}{$sub_name}));
-#	return(1);
-#}
-
 sub lookup_rule {
 	my ($self, $pkg_list, $pkg_name, $sub_name) =
 		(shift, shift, shift, shift);
 
 	foreach my $pkg_prefix (@$pkg_list) {
-#		next unless (defined($pkg_prefix));
 		next unless (exists($self->{$pkg_prefix}));
 		my $pkg_rules = $self->{$pkg_prefix};
 
@@ -86,10 +76,9 @@ sub lookup_rule {
 	return(undef);
 }
 
-
 #sub DESTROY {
 #		use Data::Dumper;
 #		print STDERR Dumper($_[0]);
 #}
 
-1;
+1;
\ No newline at end of file
